@@ -179,6 +179,8 @@ pub enum Emergency {
     Unlawful,
     #[serde(rename = "downed")]
     Downed,
+    #[serde(rename = "reserved")]
+    Reserved,
 }
 
 // Deserializes 1/0 into true/false, or None.
